/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.sundhedsdatastyrelsen.cbs.idptest;

import dk.nsp.test.idp.builder.Builders;
import dk.nsp.test.idp.model.CitizenIdentity;
import dk.nsp.test.idp.vault.RemoteCredentialVault;

import java.net.URI;
import java.util.Arrays;

public enum IdwsUser {

    CPR_2401010010("Trine Jansen", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("2401010010")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build()),
    CPR_2401010011("Jakob Jønsson Møller", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("2401010011")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build()),
    CPR_2401010012("Tinja Gregersen", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("2401010012")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build()),
    CPR_2401010013("Theiss Nielsen", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("2401010013")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build()),
    CPR_2401010014("Tashina Mathiesen", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("2401010014")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build()),
    CPR_2401010015("Thorborg Eriksen", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("2401010015")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build()),
    CPR_2401010016("Thia Christoffersen", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("2401010016")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build()),
    EXPIRED_IMMUNITY("Truels Holm", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("2401010017")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build()),
    CPR_2401010018("Helle Frost Rasmussen", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("2401010018")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build()),
    NC_CPR_0405870101("Anders Andersen", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("0405870101")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build(), false), //Vaccinated 2 dosages (completed 24/4/2021), negative test & immunity + has child cpr '3008198989'
    NC_CPR_0405870104("Dorthe Drewes", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("0405870104")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build(), false),
    NC_CPR_0405870106("Frederikke Frederiksen", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("0405870106")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build(), false), //has only a negative (not EU approved) antigen test max 28 hours old + has child cpr '3008198989'
    NC_CPR_2011451636("Åge Ågesen", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("2011451636")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build(), false), //only negative PCR max 28 hours old
    NC_CPR_1704080278("Tämirä Jäkøbsén", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("1704080278")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build(), false), //positive PCR -4 hours from 10:00 DK time
    NC_CPR_2310901373("Æske Æskesen", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("2310901373")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build(), false), //positive AG -4 hours from 10:00 DK time
    NC_CPR_2310901374("Thóra Thórasen", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("2310901374")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build(), false), //has only a positive antigen test max 28 hours old
    NC_CPR_1204933477("Torgny Madsen", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("1204933477")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build(), false),
    NC_CPR_2910781588("Trinke Larsen", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("2910781588")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build(), false), //has completed vaccination (24/4/2021) + immunity via positive PCR
    NC_CPR_2306654281("Tolver Sørensen", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("2306654281")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build(), false), //has completed vaccination (24/4/2021) + immunity via positive AG
    NC_CPR_1102962840("Ronja Lind", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("1102962840")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build(), false), //has completed vaccination (24/4/2021) + revaccination (15/9/2021) + positive AG -336 hours
    NC_CPR_1206103647("Sara Thorsen", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("1206103647")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build(), false), //has completed vaccination (24/4/2021) + booster + positive AG -347 hours
    NC_CPR_1010742357("Teis Andreasen", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("1010742357")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build(), false), //PCR/PCR Påvist/Påvist	-288 time/-1 time
    NC_CPR_3107811778("Telena Brandt", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("3107811778")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build(), false), //positive AG -336 timer
    NC_CPR_0212442684("Tinea Pedersen", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("0212442684")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build(), false), //has only a positive pcr test min 14 days old
    NC_CPR_2104262681("Lady Gaga", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("2104262681")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build(), false),
    NC_CPR_2405125656("John Johnsen", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("2405125656")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build(), false), // Barn af CPAS-104
    NC_CPR_0107066666("Albert Albertsen", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("0107066666")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build(), false), //15 år (og dermed ikke med i stamdata_child_relation)
    NC_CPR_0510740700("Terna Ray Ray Bak", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("0510740700")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build(), false), //has different addresseringsnavn + has 1/2 phizer (01/06/2021) + positive PCR min 333 hours old,
    NC_CPR_0501942071("Torres Schou", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("0501942071")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build(), false),
    NC_CPR_2705230254("Sofus Emil Kragh Nielsen", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("2705230254")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build(), false), //5 AG with manufacturer (CE / CE / unknown / HSC / HSC), taken (-160 / -136 / -112 / -88 / -12 hours from 10:00 DK time)
    NC_CPR_2009171897("Amélie Babineaux", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("2009171897")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build(), false), //has only negative (EU approved) antigen max 28 hours old
    NC_CPR_2305372528("Eugène Hamilton Lévesque", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("2305372528")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build(), false),
    NC_CPR_1105692051("Øjvind Ølgård", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("1105692051")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build(), false), //5 negative tests with type (PCR / CE / PCR / HSC / HSC), taken  (-160 / -136 / -112 / -88 / -12 hours from 10:00 DK time),
    NC_CPR_1511212961("Niels Haakon Markussen", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("1511212961")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build(), false), //positive PCR -263 hours from 10:00 DK time
    NC_CPR_1202363235("Thord Karlsen", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("1202363235")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build(), false),
    NC_CPR_1308620712("Tanna Christensen", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("1308620712")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build(), false), //positive pcr -4318 hours from 10:00 DK time,
    NC_CPR_2211282360("Anders And", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("2211282360")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build(), false), //negative PCR / AG  -73 / -72 hours from 10:00 DK time
    NC_CPR_3001333002("Tami Dahl", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("3001333002")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build(), false), //expired negative PCR -96 hours from 10:00 DK time
    NC_CPR_0208193805("Terje Tøke Davidsen", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("0208193805")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build(), false), //expired positive PCR more than 12 months old
    NC_CPR_2109624288("Tordis Ravn", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("2109624288")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build(), false), // HSC ikke påvist -4 timer
    NC_CPR_2302471279("Thorbjørn Nielsen", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("2302471279")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build(), false), //ingen tests, færdigvaccineret 01.06.21 kl.12
    NC_CPR_2906087879("Hans Nielsen", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("2906087879")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build(), false),  // Barn af CPAS-240 og CPAS-241
    NC_CPR_3006077879("Hans Jørgen Nielsen", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("3006077879")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build(), false), // Barn af CPAS-240 og CPAS-241
    NC_CPR_0106107878("Hansine Nielsen", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("0106107878")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build(), false), // Barn af CPAS-240 og CPAS-241  -- PCR (Ikke påvist) / HSC (Ikke påvist)	 -97 timer / -4 timer
    NC_CPR_0611253169("Terkild Lassen", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("0611253169")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build(), false), //two positive PCRs, -384 timer / 528 timer
    NC_CPR_2104513363("Thomas Clausen", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("2104513363")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build(), false), //two positive PCRs,  -347 timer / -528 timer. See https://nsp-dk.slack.com/archives/C01RRS1HN0M/p1636457619037700
    NC_CPR_1801293574("Sofia Poulsen", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("1801293574")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build(), false), //a positive PCR -347 timer
    NC_CPR_3012283023("Tarben Sørensen", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("3012283023")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build(), false), //PCR / PCR / PCR / HSC / HSC / unknown || Ikke påvist / Påvist / Ikke påvist / Ikke påvist / Påvist / Ikke påvist || -4 / -8 / -12 / -16 / -20 / -24 timer
    NC_CPR_2506893339("Thorlejv Knudsen", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("2506893339")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build(), false), //AG / PCR || Påvist / Påvist || -4 / -1440
    NC_CPR_0706293072("Torunn Kristoffersen", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("0706293072")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build(), false),
    NC_CPR_0712081266("Thilla Hermansen", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("0712081266")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build(), false),
    NC_CPR_1703501676("Feline Jepsen", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("1703501676")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build(), false), //En negativ PCR test -107 timer
    NC_CPR_1301071035("Mads Danielsen", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("1301071035")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build(), false), //En positiv PCR test -275 timer
    NC_CPR_1403993158("Tine Kjeldsen", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("1403993158")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build(), false), //positiv PCR -4331 timer
    NC_CPR_0301301728("Katinka Sørensen", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("0301301728")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build(), false), //user has 5 negative AG with manufacturer (CE / CE / unknown / HSC / HSC), taken (-100 / -90 / -80 / -70 / -60 hours from 10:00 DK time)
    NC_CPR_0811220950("Hansine Dam", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("0811220950")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build(), false), //En positiv PCR test -347 timer+vaccination

    NO_LAB_RESULTS("Thinus Kjeldsen", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("1505920607")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build()),
    IN_NSP_STAMDATA_BUT_NOT_IN_CPR("Tara Skov", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("0806644420")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build()),
    NOT_IN_NSP_STAMDATA("Ticho Schultz", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("3005027911")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build()),
    POWER_OF_ATTORNEY_ACTING_USER("Gitte Gregersen", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("3108732076").actingOnBehalfOf("0904983500")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build()), //har fuldmagt fra 0904983500 Gry Gregersen
    POWER_OF_ATTORNEY_PRINCIPAL_USER("Gry Gregersen", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("0904983500")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build()), //har givet fuldmagt til 3108732076 Gitte Gregersen

    GYLDIGT_IMMUNITET_PAS("Ture Toft", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("0101859568")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build()),          //(gyldig immunitet)
    PARENT_A("Thorvil Jespersen", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("0601830299")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build()),
    CHILD_OF_A("Barn af Thorvil Jespersen", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("1801137268")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build()),

    // the names on these 4 users must not be changed
    PARENT_B("Anna Andersen", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("2502801010")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build()),
    CHILD_1_OF_B("Anton Andersen", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("2503107875")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build()),
    CHILD_2_OF_B("Nadja Andersen", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("0706128662")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build()),
    CHILD_3_OF_B("Kalle Andersen", Builders.citizenIdentity().representing(Builders.citizen().identifiedBy("1005189655")).usedBy(Builders.serviceConsumer().named("Service Consumer Test").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Service_Consumer_sds.p12"), "Test1234".toCharArray(), true))).verifiedBy(Builders.identityProvider().named("https://idp.test.nspop.dk").withAudience("https://bootstrap.sts.nspop.dk/").identifiedBy(new RemoteCredentialVault(URI.create("https://www.nspop.dk/download/attachments/190481050/NSP_Test_Identity_Provider_sds.p12"), "Test1234".toCharArray(), true))).using(Builders.securityTokenService().at(URI.create("http://test1.ekstern-test.nspop.dk:8080/sts/services/Bst2Idws"))).consumedBy(Builders.serviceProvider().withAudience("https://audience.nspop.dk/cbs")).build());


    private final String name;
    private final CitizenIdentity identity;
    private final boolean allowDdvChanges;

    IdwsUser(String name, CitizenIdentity identity) {
        this.name = name;
        this.identity = identity;
        this.allowDdvChanges = true;
    }

    IdwsUser(String name, CitizenIdentity identity, boolean allowDdvChanges) {
        this.name = name;
        this.identity = identity;
        this.allowDdvChanges = allowDdvChanges;
    }

    public static IdwsUser fromName(String name) {
        return Arrays.stream(values())
            .filter(user -> user.commonName().equals(name))
            .findFirst()
            .orElse(null);
    }

    public String commonName() {
        return name;
    }

    public CitizenIdentity getIdentity() {
        return identity;
    }

    public boolean allowDdvChanges() {
        return allowDdvChanges;
    }
}
