/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.sundhedsdatastyrelsen.cbs.cbsdriver;

import dk.sosi.seal.OIOIDWSFactory;
import dk.sosi.seal.vault.CredentialVault;
import dk.sundhedsdatastyrelsen.cbs.configuration.BorgerContext;
import dk.sundhedsdatastyrelsen.cbs.configuration.RequestContext;
import dk.sundhedsdatastyrelsen.cbs.configuration.XmlDocumentResponseInterceptor;
import dk.sundhedsdatastyrelsen.cbs.idptest.NspServiceException;
import dk.sundhedsdatastyrelsen.cbs.idptest.SOAPOperation;
import dk.sundhedsdatastyrelsen.cbs.idptest.ServiceCaller;
import dk.sundhedsdatastyrelsen.cbs.idptest.IdwsUser;
import dk.sundhedsdatastyrelsen.coronapass._2021._03.coronapass_web_service.CoronaPassPort;
import dk.sundhedsdatastyrelsen.coronapass._2021._03.coronapass_web_service.GetCoronaPassRequest;
import dk.sundhedsdatastyrelsen.coronapass._2021._03.coronapass_web_service.GetCoronaPassResponse;
import org.apache.log4j.Logger;

import java.net.URI;

import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertNotNull;

public class CBSDriver {

    private static final String CBS_AUDIENCE = "https://audience.nspop.dk/cbs";
    private static final Logger log = Logger.getLogger(CBSDriver.class);

    //private final CoronaPassPort servicePort;
    //private final BorgerContext borgerContext;
    //private final RequestContext requestContext;

    private final XmlDocumentResponseInterceptor documentInterceptor;
    private final CredentialVault trustVault;
    private final OIOIDWSFactory oioIdwsFactory;

    private ServiceCaller serviceCaller = new ServiceCaller();

    private String uri = "http://localhost:8080/cbs-service/CoronaPassWebService";

    public CBSDriver(CoronaPassPort servicePort, BorgerContext borgerContext, RequestContext requestContext, XmlDocumentResponseInterceptor documentInterceptor, CredentialVault trustVault, OIOIDWSFactory oioIdwsFactory) {
        //this.servicePort = servicePort;
        //this.borgerContext = borgerContext;
        //this.requestContext = requestContext;
        this.documentInterceptor = documentInterceptor;
        this.trustVault = trustVault;
        this.oioIdwsFactory = oioIdwsFactory;
    }

    public GetCoronaPassResponse getCoronaPass(IdwsUser user) {
        return getCoronaPass(user, user.getIdentity().getCitizen().getIdentifier());
    }

    public GetCoronaPassResponse getCoronaPass(IdwsUser user, String cpr) {
        return getCoronaPass(user, cpr, null);
    }

    public GetCoronaPassResponse getCoronaPass(IdwsUser actingUser, String requestCpr, String principalUserCpr) {
        //borgerContext.clearContext();
        //requestContext.clearContext();

        //String messageId = UUID.randomUUID().toString();
        //requestContext.setRequestContext(messeageId);
        //borgerContext.setContext(CBS_AUDIENCE, actingUser, principalUserCpr);
        GetCoronaPassRequest request = new GetCoronaPassRequest();
        request.setIdentifier(requestCpr);

        //GetCoronaPassResponse response = servicePort.getCoronaPass(request);
        GetCoronaPassResponse response = null;
        try {

            response = serviceCaller.call(
                actingUser.getIdentity(),
                request,
                null,
                SOAPOperation.GetCoronaPass.getSoapAction(),
                new URI(uri),
                GetCoronaPassRequest.class,
                GetCoronaPassResponse.class);

        } catch (Exception | NspServiceException e) {

        }

        assertNotNull(response);

        return response;
    }

}
