/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.sundhedsdatastyrelsen.cbs.cbsdriver;

import dk.medcom.dgws._2006._04.dgws_1_0.Header;
import dk.nsp.test.idp.OrganizationIdentities;
import dk.sundhedsdatastyrelsen.cbs.dgws.GenericDGWSHeaderProvider;
import dk.sundhedsdatastyrelsen.cbs.idptest.NspServiceException;
import dk.sundhedsdatastyrelsen.cbs.idptest.SOAPOperation;
import dk.sundhedsdatastyrelsen.cbs.idptest.SOAPOperationRoot;
import dk.sundhedsdatastyrelsen.cbs.idptest.ServiceCaller;
import dk.sundhedsdatastyrelsen.coronapass._2021._07.eu_covid_test_certificate_signing.EUCovidTestCertificateSigningDGWSPort;
import dk.sundhedsdatastyrelsen.coronapass._2021._07.eu_covid_test_certificate_signing.GetSignedEUCovidTestCertificateRequest;
import dk.sundhedsdatastyrelsen.coronapass._2021._07.eu_covid_test_certificate_signing.GetSignedEUCovidTestCertificateResponse;
import org.oasis_open.docs.wss._2004._01.oasis_200401_wss_wssecurity_secext_1_0.Security;

import javax.xml.bind.JAXBException;
import java.net.URI;
import java.net.URISyntaxException;

public class CBSEuSigningDriver {

    //private final GenericDGWSHeaderProvider<Security, Header> headerProvider;
    //private final EUCovidTestCertificateSigningDGWSPort port;
    private ServiceCaller serviceCaller = new ServiceCaller();
    private String uri = "http://localhost:8080/cbs-service/EUCovidTestCertificateSigningService";

    public CBSEuSigningDriver() {
        //this.headerProvider = headerProvider;
        //this.port = port;
    }

    public GetSignedEUCovidTestCertificateResponse getSignedEUCovidTestCertificate(GetSignedEUCovidTestCertificateRequest request) {
        //final DGWSHeaders<Security, Header> headers = headerProvider.getHeaders();

        try {
            return serviceCaller.call(
                OrganizationIdentities.sundhedsdatastyrelsen(),
                request,
                null,
                SOAPOperation.GetSignedEUCovidTestCertificate.getSoapAction(),
                new URI(uri),
                GetSignedEUCovidTestCertificateRequest.class,
                GetSignedEUCovidTestCertificateResponse.class);

            //return port.getSignedEUCovidTestCertificate(request, headers.getSecurity(), new Holder<>(headers.getMedComHeader()));
        } catch (URISyntaxException dgwsFault) {
            throw new RuntimeException(dgwsFault);
        } catch (NspServiceException e) {
            throw new RuntimeException(e);
        } catch (JAXBException e) {
            throw new RuntimeException(e);
        }
    }
}
